Signal
======

Experimental signal is given by our model convolved with instrument response function

.. toctree::
   :maxdepth: 4

   math.signal_model.signal.cauchy
   math.signal_model.signal.gaussian
   math.signal_model.signal.pseudo_voigt
